class HelloWorldKeywords(object):
    def __init__(self):
        self.name = "Noname"

    def say_hi(self):
        """ Say hi with out argument
        Examples:
        | Say Hi |
        """
        print("Say hi " + self.name)

    def say_hi2(self, name):
        """ Say hi with a argument.
        `name` Your name
        Examples:
        Say hi   <name>
        | Say Hi | somkiat |
        """
        self.name = name
        print("Say hi " + self.name)



from setuptools import setup

setup(
    name="chain-helloworld-library",
    version='1.0',
    package_dir={'' : 'src'},
    packages=['HelloWorld'],
    url='https://github.com/kachain2019/demo-helloworld-library',
    author='kachain',
    author_email='kachain2019.a@gmail.com',
)



from HelloWorldKeywords import HelloWorldKeywords

class HelloWorld(HelloWorldKeywords):

    """ A keyword library for Robot Framework. It provides keywords for
        learning how to create a new library. For more information
        on underlying methods and documentation, see:
            http://eclipse.org/paho/clients/python/docs/
    """

    ROBOT_LIBRARY_SCOPE = 'TEST_CASE'
